@@ -313,11 +313,14 @@ class Top2Vec:
             logger.info('Pre-processing documents for training')
 
             # preprocess documents
-            train_corpus = [' '.join(tokenizer(doc)) for doc in documents]
+            tokenized_corpus = [tokenizer(doc) for doc in documents]
+
+            def return_doc(doc):
+                return doc
 
             # preprocess vocabulary
-            vectorizer = CountVectorizer()
-            doc_word_counts = vectorizer.fit_transform(train_corpus)
+            vectorizer = CountVectorizer(tokenizer=return_doc, preprocessor=return_doc)
+            doc_word_counts = vectorizer.fit_transform(tokenized_corpus)
             words = vectorizer.get_feature_names()
             word_counts = np.array(np.sum(doc_word_counts, axis=0).tolist()[0])
             vocab_inds = np.where(word_counts > min_count)[0]
@@ -339,6 +342,7 @@ class Top2Vec:
             if use_embedding_model_tokenizer:
                 self.document_vectors = self._embed_documents(documents)
             else:
+                train_corpus = [' '.join(tokens) for tokens in tokenized_corpus]
                 self.document_vectors = self._embed_documents(train_corpus)
 
         else:
@@ -417,6 +421,9 @@ class Top2Vec:
             File where model will be saved.
         """
 
+        document_index_temp = None
+        word_index_temp = None
+
         # do not save sentence encoders and sentence transformers
         if self.embedding_model != "doc2vec":
             self.embed = None
@@ -427,6 +434,7 @@ class Top2Vec:
             self.document_index.save_index(temp.name)
             self.serialized_document_index = temp.read()
             temp.close()
+            document_index_temp = self.document_index
             self.document_index = None
 
         # serialize word index so that it can be saved
@@ -435,10 +443,14 @@ class Top2Vec:
             self.word_index.save_index(temp.name)
             self.serialized_word_index = temp.read()
             temp.close()
+            word_index_temp = self.word_index
             self.word_index = None
 
         dump(self, file)
 
+        self.document_index = document_index_temp
+        self.word_index = word_index_temp
+
     @classmethod
     def load(cls, file):
         """
